function [R0,phi]=R0_A(N,flag_model,flag_method,par)

%  Copyright (c) 2020-2021 Dimitri Breda.
%  R0_A is distributed under the terms of the MIT license.
%
%  If you use this software for a scientific publication,
%  please cite the following publications:
%
%  [1] D. Breda, F. Florian, J. Ripoll, R. Vermiglio,Efficient numerical computation
%      of the basic reproduction number for structured populations, Journal of Computational
%      and Applied Mathematics, https://doi.org/10.1016/j.cam.2020.113165.
%
%  [2] D. Breda, T. Kuniya, J. Ripoll, R. Vermiglio, Collocation of Next-Generation 
%      Operators for Computing the Basic Reproduction Number of Structured Populations. 
%      J Sci Comput, https://doi.org/10.1007/s10915-020-01339-1.
%
%   R0_A numerical computation of R_0.
%   [R0,phi]=R0_A(N,flag_model,flag_method,par) returns the pseudospectral
%   collocation approximation of the basic reproduction number for the
%   class of models A (cell population models).
%   INPUT:
%              N: degree of discretization (1x1)
%     flag_model: choice of model coefficients (1x1)
%    flag_method: 1=old, 2=new, 3=no diffusion (1x1)
%            par: vector of possible parameters (px1)
%   OUTPUT:
%             R0: approximation of R_0 (1x1)
%            phi: barycentric polynomial approximation of relevant 
%                 eigenfunction on 1000 equispaced points in [0,l] (1000x1)

%% model coefficients
l=1;
c=@(x)l^2-x.^2;
if flag_model==1 % constant vital rates, smooth
    dtilde=2;
    mutilde=1;
    mu=@(x)mutilde*ones(size(x));
    betatilde=3;
    beta=@(x)betatilde*ones(size(x));
    %R0=1.5
elseif flag_model==2 % general, smooth
    dtilde=par(1);
    mutilde=1;
    mu=@(x)mutilde*x/l;
    betatilde=3;
    beta=@(x)betatilde*((x.^2).*(l-x)*27/(2*l^3)+1);
    %R0=1.853050859715361, N=1000, dtilde=2; (new)
    %R0=1.504307446573413, N=1000, dtilde=1e-6; (new)
    %R0=1.621272061691218, N=1000, no diffusion; (new)
elseif flag_model==3 % general, non-smooth
    dtilde=par(1);
    mutilde=1;
    mu=@(x)mutilde*x/l;
    betatilde=3;
    beta=@(x)betatilde*(1+ceil(x-l/2));
    %R0=1.798169690353490, N=1000, dtilde=2; (new)
end
d=@(x)dtilde*(2+sin(1*pi*x));
% d=@(x)dtilde*(x.*(l-x)*4/(l^2)+1);

%% Chebyshev nodes and diff. matrix
[H,x]=difmat(0,l,N);

%% birth operator
if flag_method==1
    B=2*diag([0;beta(x(2:N));0]);
elseif flag_method==2
    B=2*diag([0;beta(x(2:N+1))]);
elseif flag_method==3
    B=2*diag([0;beta(x(2:N+1))]);
end

%% mortality operator
C=diag(c(x));
D=diag(d(x));
Sigma=diag(beta(x)+mu(x));
if flag_method==1
    M=H*(C-D*H)+Sigma;
    M(1,:)=D(1,1)*H(1,:);
    M(1,1)=M(1,1)-C(1,1);
    M(N+1,:)=D(N+1,N+1)*H(N+1,:);
    M(N+1,N+1)=M(N+1,N+1)-C(N+1,N+1);
elseif flag_method==2
    M=zeros(N+1);
    M(1,:)=D(N,N)*H(N+1,:);
    M(1,N+1)=M(1,N+1)-C(N,N+1);
    M(2:N+1,:)=H(2:N+1,2:N+1)*(C(2:N+1,:)-D(2:N+1,:)*H)+Sigma(2:N+1,:);
elseif flag_method==3
    M=H*C+diag(beta(x)+mu(x));
    M(1,:)=[c(0),zeros(1,N)];
end

%% eigenvalue problem
% [Phi,R0]=eig(B,M);
[Psi,R0]=eig(B/M);Phi=M\Psi;
R0=abs(diag(R0));
[R0,ind]=sort(R0,'descend');
R0=R0(1);
Phi=Phi(:,ind);
Phi=Phi(:,1)/Phi(1,1);
xx=linspace(0,l,1000)';
phi=bary(xx,Phi,x,bary_weights(x));
% plot(xx,phi,'-k')